# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/advanced.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..stream import connection_pb2 as blickfeld_dot_stream_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/advanced.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1f\x62lickfeld/config/advanced.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\x1a!blickfeld/stream/connection.proto\"\xaa\x03\n\x08\x41\x64vanced\x12>\n\x08\x64\x65tector\x18\x01 \x01(\x0b\x32,.blickfeld.protocol.config.Advanced.Detector\x12\x42\n\nprocessing\x18\x02 \x01(\x0b\x32..blickfeld.protocol.config.Advanced.Processing\x12:\n\x06server\x18\x03 \x01(\x0b\x32*.blickfeld.protocol.config.Advanced.Server\x1a:\n\x08\x44\x65tector\x12.\n\x0bsensitivity\x18\x01 \x01(\x02:\x01\x31\x42\x16\x81\xb5\x18\x9a\x99\x99\x99\x99\x99\xe9?\x89\xb5\x18\x33\x33\x33\x33\x33\x33\xf3?\x1a=\n\nProcessing\x12/\n\x0crange_offset\x18\x01 \x01(\x02:\x01\x30\x42\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\x00\xc0\x89\xb5\x18\x00\x00\x00\x00\x00\x00\x00@\x1a\x63\n\x06Server\x12Y\n default_point_cloud_subscription\x18\x01 \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloud')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_stream_dot_connection__pb2.DESCRIPTOR,])




_ADVANCED_DETECTOR = _descriptor.Descriptor(
  name='Detector',
  full_name='blickfeld.protocol.config.Advanced.Detector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='blickfeld.protocol.config.Advanced.Detector.sensitivity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\232\231\231\231\231\231\351?\211\265\030333333\363?'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=385,
)

_ADVANCED_PROCESSING = _descriptor.Descriptor(
  name='Processing',
  full_name='blickfeld.protocol.config.Advanced.Processing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_offset', full_name='blickfeld.protocol.config.Advanced.Processing.range_offset', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\201\265\030\000\000\000\000\000\000\000\300\211\265\030\000\000\000\000\000\000\000@'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=448,
)

_ADVANCED_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='blickfeld.protocol.config.Advanced.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_point_cloud_subscription', full_name='blickfeld.protocol.config.Advanced.Server.default_point_cloud_subscription', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=549,
)

_ADVANCED = _descriptor.Descriptor(
  name='Advanced',
  full_name='blickfeld.protocol.config.Advanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector', full_name='blickfeld.protocol.config.Advanced.detector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processing', full_name='blickfeld.protocol.config.Advanced.processing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server', full_name='blickfeld.protocol.config.Advanced.server', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ADVANCED_DETECTOR, _ADVANCED_PROCESSING, _ADVANCED_SERVER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=549,
)

_ADVANCED_DETECTOR.containing_type = _ADVANCED
_ADVANCED_PROCESSING.containing_type = _ADVANCED
_ADVANCED_SERVER.fields_by_name['default_point_cloud_subscription'].message_type = blickfeld_dot_stream_dot_connection__pb2._SUBSCRIBE_POINTCLOUD
_ADVANCED_SERVER.containing_type = _ADVANCED
_ADVANCED.fields_by_name['detector'].message_type = _ADVANCED_DETECTOR
_ADVANCED.fields_by_name['processing'].message_type = _ADVANCED_PROCESSING
_ADVANCED.fields_by_name['server'].message_type = _ADVANCED_SERVER
DESCRIPTOR.message_types_by_name['Advanced'] = _ADVANCED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Advanced = _reflection.GeneratedProtocolMessageType('Advanced', (_message.Message,), dict(

  Detector = _reflection.GeneratedProtocolMessageType('Detector', (_message.Message,), dict(
    DESCRIPTOR = _ADVANCED_DETECTOR,
    __module__ = 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Detector)
    ))
  ,

  Processing = _reflection.GeneratedProtocolMessageType('Processing', (_message.Message,), dict(
    DESCRIPTOR = _ADVANCED_PROCESSING,
    __module__ = 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Processing)
    ))
  ,

  Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), dict(
    DESCRIPTOR = _ADVANCED_SERVER,
    __module__ = 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Server)
    ))
  ,
  DESCRIPTOR = _ADVANCED,
  __module__ = 'blickfeld.config.advanced_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced)
  ))
_sym_db.RegisterMessage(Advanced)
_sym_db.RegisterMessage(Advanced.Detector)
_sym_db.RegisterMessage(Advanced.Processing)
_sym_db.RegisterMessage(Advanced.Server)


_ADVANCED_DETECTOR.fields_by_name['sensitivity']._options = None
_ADVANCED_PROCESSING.fields_by_name['range_offset']._options = None
# @@protoc_insertion_point(module_scope)
