# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/stream/connection.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import options_pb2 as blickfeld_dot_options__pb2
from ..config import algorithm_pb2 as blickfeld_dot_config_dot_algorithm__pb2
from ..data import frame_pb2 as blickfeld_dot_data_dot_frame__pb2
from ..config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/stream/connection.proto',
  package='blickfeld.protocol.stream',
  syntax='proto2',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n!blickfeld/stream/connection.proto\x12\x19\x62lickfeld.protocol.stream\x1a\x17\x62lickfeld/options.proto\x1a blickfeld/config/algorithm.proto\x1a\x1a\x62lickfeld/data/frame.proto\x1a#blickfeld/config/scan_pattern.proto\"\xa4\x05\n\tSubscribe\x12\x46\n\x0bpoint_cloud\x18\x0b \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloudH\x00\x12=\n\x06status\x18\x0c \x01(\x0b\x32+.blickfeld.protocol.stream.Subscribe.StatusH\x00\x12\x43\n\tdeveloper\x18\r \x01(\x0b\x32..blickfeld.protocol.stream.Subscribe.DeveloperH\x00\x12@\n\x08raw_file\x18\x0e \x01(\x0b\x32,.blickfeld.protocol.stream.Subscribe.RawFileH\x00\x1a\xfa\x01\n\nPointCloud\x12\x41\n\x0freference_frame\x18\x01 \x01(\x0b\x32\x1e.blickfeld.protocol.data.FrameB\x08\xb0\xb5\x18\x01\xb8\xb5\x18\x01\x12=\n\x06\x66ilter\x18\x02 \x01(\x0b\x32-.blickfeld.protocol.config.ScanPattern.Filter\x12\x38\n\nalgorithms\x18\x03 \x03(\x0b\x32$.blickfeld.protocol.config.Algorithm\x12\x30\n\"prepend_advanced_config_algorithms\x18\x04 \x01(\x08:\x04true\x1a\x08\n\x06Status\x1aY\n\x07RawFile\x12\x46\n\x0bpoint_cloud\x18\x01 \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloudH\x00\x42\x06\n\x04\x64\x61ta\x1a\x1f\n\tDeveloper*\x08\x08\x01\x10\x80\x80\x80\x80\x02:\x08\x92\xa6\x1d\x04\x08\x01\x10\x00\x42\x06\n\x04\x64\x61taB\x03\xf8\x01\x01')
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_config_dot_algorithm__pb2.DESCRIPTOR,blickfeld_dot_data_dot_frame__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,])




_SUBSCRIBE_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='blickfeld.protocol.stream.Subscribe.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_frame', full_name='blickfeld.protocol.stream.Subscribe.PointCloud.reference_frame', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\260\265\030\001\270\265\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='blickfeld.protocol.stream.Subscribe.PointCloud.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithms', full_name='blickfeld.protocol.stream.Subscribe.PointCloud.algorithms', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prepend_advanced_config_algorithms', full_name='blickfeld.protocol.stream.Subscribe.PointCloud.prepend_advanced_config_algorithms', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=723,
)

_SUBSCRIBE_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='blickfeld.protocol.stream.Subscribe.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=733,
)

_SUBSCRIBE_RAWFILE = _descriptor.Descriptor(
  name='RawFile',
  full_name='blickfeld.protocol.stream.Subscribe.RawFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Subscribe.RawFile.point_cloud', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Subscribe.RawFile.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=735,
  serialized_end=824,
)

_SUBSCRIBE_DEVELOPER = _descriptor.Descriptor(
  name='Developer',
  full_name='blickfeld.protocol.stream.Subscribe.Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\222\246\035\004\010\001\020\000'),
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=857,
)

_SUBSCRIBE = _descriptor.Descriptor(
  name='Subscribe',
  full_name='blickfeld.protocol.stream.Subscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='blickfeld.protocol.stream.Subscribe.point_cloud', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='blickfeld.protocol.stream.Subscribe.status', index=1,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='blickfeld.protocol.stream.Subscribe.developer', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_file', full_name='blickfeld.protocol.stream.Subscribe.raw_file', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBSCRIBE_POINTCLOUD, _SUBSCRIBE_STATUS, _SUBSCRIBE_RAWFILE, _SUBSCRIBE_DEVELOPER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='blickfeld.protocol.stream.Subscribe.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=189,
  serialized_end=865,
)

_SUBSCRIBE_POINTCLOUD.fields_by_name['reference_frame'].message_type = blickfeld_dot_data_dot_frame__pb2._FRAME
_SUBSCRIBE_POINTCLOUD.fields_by_name['filter'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN_FILTER
_SUBSCRIBE_POINTCLOUD.fields_by_name['algorithms'].message_type = blickfeld_dot_config_dot_algorithm__pb2._ALGORITHM
_SUBSCRIBE_POINTCLOUD.containing_type = _SUBSCRIBE
_SUBSCRIBE_STATUS.containing_type = _SUBSCRIBE
_SUBSCRIBE_RAWFILE.fields_by_name['point_cloud'].message_type = _SUBSCRIBE_POINTCLOUD
_SUBSCRIBE_RAWFILE.containing_type = _SUBSCRIBE
_SUBSCRIBE_RAWFILE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE_RAWFILE.fields_by_name['point_cloud'])
_SUBSCRIBE_RAWFILE.fields_by_name['point_cloud'].containing_oneof = _SUBSCRIBE_RAWFILE.oneofs_by_name['data']
_SUBSCRIBE_DEVELOPER.containing_type = _SUBSCRIBE
_SUBSCRIBE.fields_by_name['point_cloud'].message_type = _SUBSCRIBE_POINTCLOUD
_SUBSCRIBE.fields_by_name['status'].message_type = _SUBSCRIBE_STATUS
_SUBSCRIBE.fields_by_name['developer'].message_type = _SUBSCRIBE_DEVELOPER
_SUBSCRIBE.fields_by_name['raw_file'].message_type = _SUBSCRIBE_RAWFILE
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['point_cloud'])
_SUBSCRIBE.fields_by_name['point_cloud'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['status'])
_SUBSCRIBE.fields_by_name['status'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['developer'])
_SUBSCRIBE.fields_by_name['developer'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
_SUBSCRIBE.oneofs_by_name['data'].fields.append(
  _SUBSCRIBE.fields_by_name['raw_file'])
_SUBSCRIBE.fields_by_name['raw_file'].containing_oneof = _SUBSCRIBE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['Subscribe'] = _SUBSCRIBE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subscribe = _reflection.GeneratedProtocolMessageType('Subscribe', (_message.Message,), dict(

  PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_POINTCLOUD,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.PointCloud)
    ))
  ,

  Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_STATUS,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Status)
    ))
  ,

  RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_RAWFILE,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.RawFile)
    ))
  ,

  Developer = _reflection.GeneratedProtocolMessageType('Developer', (_message.Message,), dict(
    DESCRIPTOR = _SUBSCRIBE_DEVELOPER,
    __module__ = 'blickfeld.stream.connection_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe.Developer)
    ))
  ,
  DESCRIPTOR = _SUBSCRIBE,
  __module__ = 'blickfeld.stream.connection_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.stream.Subscribe)
  ))
_sym_db.RegisterMessage(Subscribe)
_sym_db.RegisterMessage(Subscribe.PointCloud)
_sym_db.RegisterMessage(Subscribe.Status)
_sym_db.RegisterMessage(Subscribe.RawFile)
_sym_db.RegisterMessage(Subscribe.Developer)


DESCRIPTOR._options = None
_SUBSCRIBE_POINTCLOUD.fields_by_name['reference_frame']._options = None
_SUBSCRIBE_DEVELOPER._options = None
# @@protoc_insertion_point(module_scope)
